# OctoprintProgress


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**completion** | **float** |  | 
**filepos** | **int** |  | 
**print_time** | **int** |  | 
**print_time_left** | **int** |  | 
**print_time_origin** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


